diff --git a/include/v8.h b/include/v8.h
index 78b4613..b64c679 100644
--- a/include/v8.h
+++ b/include/v8.h
@@ -113,6 +113,7 @@ class Array;
 class Int32;
 class Uint32;
 class External;
+class Blob;
 class Primitive;
 class Boolean;
 class Integer;
@@ -724,6 +725,11 @@ class V8EXPORT Value : public Data {
   bool IsExternal() const;
 
   /**
+   * Returns true if this value is blob.
+   */
+  bool IsBlob() const;
+
+  /**
    * Returns true if this value is a 32-bit signed integer.
    */
   bool IsInt32() const;
@@ -1381,6 +1387,28 @@ class V8EXPORT External : public Value {
 };
 
 
+/**
+ * A JavaScript value that wraps a ByteArray.
+ */
+class V8EXPORT Blob : public Value {
+ public:
+  // Create a Blob with room for 'length' bytes.
+  static Local<Blob> New(int length);
+  static inline Blob* Cast(Value* obj);
+
+  // Read the index'th byte integer
+  uint8_t GetByte(int index);
+  // Write the index'th byte
+  void SetByte(int index, uint8_t value);
+  // Get access to the raw memory
+  uint8_t* GetAddress();
+  int ByteCount();
+ private:
+  Blob();
+  static void CheckCast(v8::Value* obj);
+};
+
+
 // --- T e m p l a t e s ---
 
 
@@ -3177,6 +3205,14 @@ External* External::Cast(v8::Value* value) {
 }
 
 
+Blob* Blob::Cast(v8::Value* value) {
+#ifdef V8_ENABLE_CHECKS
+  CheckCast(value);
+#endif
+  return static_cast<Blob*>(value);
+}
+
+
 Local<Value> AccessorInfo::Data() const {
   return Local<Value>(reinterpret_cast<Value*>(&args_[-3]));
 }
diff --git a/src/api.cc b/src/api.cc
index 00b590f..8756c0b 100644
--- a/src/api.cc
+++ b/src/api.cc
@@ -1516,6 +1516,12 @@ bool Value::IsExternal() const {
 }
 
 
+bool Value::IsBlob() const {
+  if (IsDeadCheck("v8::Value::IsBlob()")) return false;
+  return Utils::OpenHandle(this)->IsByteArray();
+}
+
+
 bool Value::IsInt32() const {
   if (IsDeadCheck("v8::Value::IsInt32()")) return false;
   i::Handle<i::Object> obj = Utils::OpenHandle(this);
@@ -1643,6 +1649,15 @@ void External::CheckCast(v8::Value* that) {
 }
 
 
+void Blob::CheckCast(v8::Value* that) {
+  if (IsDeadCheck("v8::Blob::Cast()")) return;
+  i::Handle<i::Object> obj = Utils::OpenHandle(that);
+  ApiCheck(obj->IsByteArray(),
+           "v8::Blob::Cast()",
+           "Could not convert to external");
+}
+
+
 void v8::Object::CheckCast(Value* that) {
   if (IsDeadCheck("v8::Object::Cast()")) return;
   i::Handle<i::Object> obj = Utils::OpenHandle(that);
@@ -2954,6 +2969,42 @@ void* External::Value() const {
 }
 
 
+Local<Blob> v8::Blob::New(int length) {
+  LOG_API("Blob::New");
+  EnsureInitialized("v8::Blob::New()");
+  ENTER_V8;
+  return Utils::ToLocal(i::Factory::NewByteArray(length));
+}
+
+
+int Blob::ByteCount() {
+  if (IsDeadCheck("v8::Blob::ByteCount()")) return 0;
+  i::Handle<i::Object> obj = Utils::OpenHandle(this);
+  return i::ByteArray::cast(*obj)->length();
+}
+
+
+uint8_t Blob::GetByte(int index) {
+  if (IsDeadCheck("v8::Blob::GetByte()")) return 0;
+  i::Handle<i::Object> obj = Utils::OpenHandle(this);
+  return i::ByteArray::cast(*obj)->get(index);
+}
+
+
+void Blob::SetByte(int index, uint8_t value) {
+  if (IsDeadCheck("v8::Blob::SetByte()")) return;
+  i::Handle<i::Object> obj = Utils::OpenHandle(this);
+  i::ByteArray::cast(*obj)->set(index, value);
+}
+
+
+uint8_t* Blob::GetAddress() {
+  if (IsDeadCheck("v8::Blob::GetAddress()")) return NULL;
+  i::Handle<i::Object> obj = Utils::OpenHandle(this);
+  return i::ByteArray::cast(*obj)->GetDataStartAddress();
+}
+
+
 Local<String> v8::String::Empty() {
   EnsureInitialized("v8::String::Empty()");
   LOG_API("String::Empty()");
diff --git a/src/api.h b/src/api.h
index a28e1f0..b1f819b 100644
--- a/src/api.h
+++ b/src/api.h
@@ -190,6 +190,8 @@ class Utils {
       v8::internal::Handle<v8::internal::JSArray> obj);
   static inline Local<External> ToLocal(
       v8::internal::Handle<v8::internal::Proxy> obj);
+  static inline Local<Blob> ToLocal(
+      v8::internal::Handle<v8::internal::ByteArray> obj);
   static inline Local<Message> MessageToLocal(
       v8::internal::Handle<v8::internal::Object> obj);
   static inline Local<Number> NumberToLocal(
@@ -235,6 +237,8 @@ class Utils {
       OpenHandle(const v8::TypeSwitch* that);
   static inline v8::internal::Handle<v8::internal::Proxy>
       OpenHandle(const v8::External* that);
+  static inline v8::internal::Handle<v8::internal::ByteArray>
+      OpenHandle(const v8::Blob* that);
 };
 
 
@@ -266,6 +270,7 @@ MAKE_TO_LOCAL(ToLocal, String, String)
 MAKE_TO_LOCAL(ToLocal, JSObject, Object)
 MAKE_TO_LOCAL(ToLocal, JSArray, Array)
 MAKE_TO_LOCAL(ToLocal, Proxy, External)
+MAKE_TO_LOCAL(ToLocal, ByteArray, Blob)
 MAKE_TO_LOCAL(ToLocal, FunctionTemplateInfo, FunctionTemplate)
 MAKE_TO_LOCAL(ToLocal, ObjectTemplateInfo, ObjectTemplate)
 MAKE_TO_LOCAL(ToLocal, SignatureInfo, Signature)
@@ -301,6 +306,7 @@ MAKE_OPEN_HANDLE(Function, JSFunction)
 MAKE_OPEN_HANDLE(Message, JSObject)
 MAKE_OPEN_HANDLE(Context, Context)
 MAKE_OPEN_HANDLE(External, Proxy)
+MAKE_OPEN_HANDLE(Blob, ByteArray)
 
 #undef MAKE_OPEN_HANDLE
 
diff --git a/test/cctest/test-api.cc b/test/cctest/test-api.cc
index 475cdf8..4d8b368 100644
--- a/test/cctest/test-api.cc
+++ b/test/cctest/test-api.cc
@@ -1404,6 +1404,39 @@ THREADED_TEST(External) {
 }
 
 
+THREADED_TEST(Blob) {
+  v8::HandleScope scope;
+  Local<v8::Blob> blob = v8::Blob::New(3);
+  blob->SetByte(0, 10);
+  blob->SetByte(1, 11);
+  blob->SetByte(2, 12);
+  LocalContext env;
+  env->Global()->Set(v8_str("blob"), blob);
+  Local<Value> reblob_obj = Script::Compile(v8_str("this.blob"))->Run();
+  v8::Handle<v8::Blob> reblob = v8::Handle<v8::Blob>::Cast(reblob_obj);
+  int count = reblob->ByteCount();
+  CHECK_EQ(3, count);
+
+  uint8_t b = reblob->GetByte(0);
+  CHECK_EQ(10, b);
+
+  b = reblob->GetByte(1);
+  CHECK_EQ(11, b);
+
+  b = reblob->GetByte(2);
+  CHECK_EQ(12, b);
+
+  uint8_t *p = reblob->GetAddress();
+  CHECK_EQ(10, p[0]);
+  CHECK_EQ(11, p[1]);
+  CHECK_EQ(12, p[2]);
+
+  p[2] = 52;
+  b = reblob->GetByte(2);
+  CHECK_EQ(52, b);
+}
+
+
 THREADED_TEST(GlobalHandle) {
   v8::Persistent<String> global;
   {
